import Vue from 'vue'
import Router from 'vue-router'

Vue.use(Router)

/* Layout */
import Layout from '@/layout'

/* Router Modules */
// import componentsRouter from './modules/components'
// import chartsRouter from './modules/charts'
// import tableRouter from './modules/table'
// import nestedRouter from './modules/nested'

/**
 * Note: sub-menu only appear when route children.length >= 1
 * Detail see: https://panjiachen.github.io/vue-element-admin-site/guide/essentials/router-and-nav.html
 *
 * hidden: true                   if set true, item will not show in the sidebar(default is false)
 * alwaysShow: true               if set true, will always show the root menu
 *                                if not set alwaysShow, when item has more than one children route,
 *                                it will becomes nested mode, otherwise not show the root menu
 * redirect: noRedirect           if set noRedirect will no redirect in the breadcrumb
 * name:'router-name'             the name is used by <keep-alive> (must set!!!)
 * meta : {
    roles: ['admin','editor']    control the page roles (you can set multiple roles)
    title: 'title'               the name show in sidebar and breadcrumb (recommend set)
    icon: 'svg-name'/'el-icon-x' the icon show in the sidebar
    noCache: true                if set true, the page will no be cached(default is false)
    affix: true                  if set true, the tag will affix in the tags-view
    breadcrumb: false            if set false, the item will hidden in breadcrumb(default is true)
    activeMenu: '/example/list'  if set path, the sidebar will highlight the path you set
  }
 */

/**
 * constantRoutes
 * a base page that does not have permission requirements
 * all roles can be accessed
 */
export const constantRoutes = [
  {
    path: '/redirect',
    component: Layout,
    hidden: true,
    children: [
      {
        path: '/redirect/:path(.*)',
        component: () => import('@/views/redirect/index')
      }
    ]
  },
  {
    path: '/login',
    component: () => import('@/views/login/index'),
    hidden: true
  },
  {
    path: '/auth-redirect',
    component: () => import('@/views/login/auth-redirect'),
    hidden: true
  },
  {
    path: '/404',
    component: () => import('@/views/error-page/404'),
    hidden: true
  },
  {
    path: '/401',
    component: () => import('@/views/error-page/401'),
    hidden: true
  },
  {
    path: '/',
    component: Layout,
    redirect: '/dashboard',
    hidden: true,
    children: [
      {
        path: 'dashboard',
        component: () => import('@/views/dashboard/index'),
        name: 'Dashboard',
        meta: { title: 'dashboard', icon: 'dashboard', affix: true }
      }
    ]
  },
  {
    path: '/icon',
    component: Layout,
    hidden: true,
    children: [
      {
        path: 'index',
        component: () => import('@/views/icons/index'),
        name: 'Icons',
        meta: { title: 'icons', icon: 'icon', noCache: true }
      }
    ]
  },
  {
    path: '*', // 匹配未定义的路由
    redirect: '/dashboard', // 重定向
    hidden: true
  }/* ,
  {
    path: '*', // 匹配未定义的路由
    redirect: '/404', // 重定向
    hidden: true
  } */
  // tableRouter
  // {
  //   path: '/documentation',
  //   component: Layout,
  //   redirect: '/documentation/index',
  //   children: [
  //     {
  //       path: 'index',
  //       component: () => import('@/views/documentation/index'),
  //       name: 'Documentation',
  //       meta: { title: 'documentation', icon: 'documentation', affix: true }
  //     }
  //   ]
  // },
  // {
  //   path: '/guide',
  //   component: Layout,
  //   redirect: '/guide/index',
  //   children: [
  //     {
  //       path: 'index',
  //       component: () => import('@/views/guide/index'),
  //       name: 'Guide',
  //       meta: { title: 'guide', icon: 'guide', noCache: true }
  //     }
  //   ]
  // },
  // {
  //   path: '/profile',
  //   component: Layout,
  //   redirect: '/profile/index',
  //   hidden: true,
  //   children: [
  //     {
  //       path: 'index',
  //       component: () => import('@/views/profile/index'),
  //       name: 'Profile',
  //       meta: { title: 'profile', icon: 'user', noCache: true }
  //     }
  //   ]
  // }
]

/**
 * asyncRoutes
 * the routes that need to be dynamically loaded based on user roles
 */
export const asyncRoutes = [
  {
    path: '/announcement',
    component: Layout,
    redirect: '/index',
    meta: {
      icon: 'documentation',
      title: '公告',
      pername: 'announcement'
    },
    children: [
      {
        path: 'index',
        component: () => import('@/views/announcement/index'),
        name: 'Announcement',
        meta: { title: '登录公告', pername: 'announcement' }
      },
      {
        path: 'ingame',
        component: () => import('@/views/ingameannouncement/index'),
        name: 'IngameAnnouncement',
        meta: { title: '游戏内公告', pername: 'announcement' }
      }
    ]
  }, {
    path: '/audit',
    component: Layout,
    redirect: '/index',
    meta: {
      pername: 'audit'
    },
    children: [
      {
        path: 'index',
        component: () => import('@/views/audit/index'),
        name: 'Audit',
        meta: { title: '审核', icon: 'audit', pername: 'audit' }
      }
    ]
  }, {
    path: '/email',
    component: Layout,
    redirect: '/index',
    meta: {
      title: '邮件',
      icon: 'email',
      pername: 'listemail'
    },
    children: [
      {
        path: 'index',
        component: () => import('@/views/email/list'),
        name: 'EmailList',
        meta: { title: '邮件列表', pername: 'listemail' },
        hidden: false
      },
      {
        path: 'create',
        component: () => import('@/views/email/create'),
        name: 'EmailCreate',
        meta: { title: '发布邮件', pername: 'createemail' },
        hidden: false
      }, {
        path: 'update/:mailid',
        component: () => import('@/views/email/create'),
        name: 'EmailUpdate',
        meta: { title: '修改邮件', pername: 'editemail' },
        hidden: true
      }, {
        path: 'user_group/index',
        component: () => import('@/views/email/user_group_list'),
        name: 'UserGroupList',
        meta: { title: '用户组列表', pername: 'emailgroup' },
        hidden: true
      }, {
        path: 'user_group/member',
        component: () => import('@/views/email/group_member'),
        name: 'GroupMember',
        meta: { title: '组成员', pername: 'emailgroupmember' },
        hidden: true
      }
    ]
  }, {
    path: '/player',
    component: Layout,
    redirect: '/index',
    meta: {
      title: '玩家信息查询',
      icon: 'user',
      pername: 'playerinfo'
    },
    children: [
      {
        path: 'info',
        component: () => import('@/views/player/info'),
        name: 'playerinfo',
        meta: { title: '玩家查询', pername: 'playerinfo' },
        hidden: false
      }, {
        path: 'bagquery',
        component: () => import('@/views/player/bagquery'),
        name: 'bagquery',
        meta: { title: '玩家背包查询', pername: 'bagquery' },
        hidden: false
      }, {
        path: 'heroesquery',
        component: () => import('@/views/player/heroesquery'),
        name: 'heroesquery',
        meta: { title: '玩家英雄查询', pername: 'heroesquery' },
        hidden: false
      }, {
        path: 'goldbullionquery',
        component: () => import('@/views/player/goldbullionquery'),
        name: 'goldquery',
        meta: { title: '金币查询', pername: 'goldbullionquery' },
        hidden: false
      }, {
        path: 'ticketconsumequery',
        component: () => import('@/views/player/ticketconsumequery'),
        name: 'ticketquery',
        meta: { title: '门票消耗查询', pername: 'ticketconsumequery' },
        hidden: false
      }, {
        path: 'gamemallquery',
        component: () => import('@/views/player/gamemallquery'),
        name: 'gamemallquery',
        meta: { title: '游戏内商品查询', pername: 'gamemallquery' },
        hidden: false
      }, {
        path: 'inapporderquery',
        component: () => import('@/views/player/inapporderquery'),
        name: 'inapporderquery',
        meta: { title: '游戏内购订单查询', pername: 'inapporderquery' },
        hidden: false
      }, {
        path: 'rechargequery',
        component: () => import('@/views/player/rechargequery'),
        name: 'rechargequery',
        meta: { title: '充值查询', pername: 'rechargequery' },
        hidden: false
      }, {
        path: 'vipbindquery',
        component: () => import('@/views/player/vipbindquery'),
        name: 'vipbindquery',
        meta: { title: 'vip绑定查询', pername: 'vipbindquery' },
        hidden: false
      }, {
        path: 'vipuserquery',
        component: () => import('@/views/player/vipuserquery'),
        name: 'vipuserquery',
        meta: { title: 'vip信息查询', pername: 'vipuserquery' },
        hidden: false
      }
    ]
  }, {
    path: '/nft',
    component: Layout,
    redirect: '/index',
    meta: {
      title: '商业信息查询',
      icon: 'shopping',
      pername: 'orderquery'
    },
    children: [
      {
        path: 'orderquery',
        component: () => import('@/views/nft/orderquery'),
        name: 'orderquery',
        meta: { title: '订单查询', pername: 'orderquery' },
        hidden: false
      }, {
        path: 'salequery',
        component: () => import('@/views/nft/salequery'),
        name: 'salequery',
        meta: { title: '售卖查询', pername: 'salequery' },
        hidden: false
      }, {
        path: 'nftquery',
        component: () => import('@/views/nft/nftquery'),
        name: 'nftquery',
        meta: { title: 'NFT查询', pername: 'nftquery' },
        hidden: false
      }, {
        path: 'balancequery',
        component: () => import('@/views/nft/balancequery'),
        name: 'balancequery',
        meta: { title: '余额查询', pername: 'balancequery' },
        hidden: false
      }
    ]
  }, {
    path: '/gameswitch',
    component: Layout,
    redirect: '/index',
    meta: {
      title: '设置',
      icon: 'el-icon-setting',
      pername: 'gameswitch'
    },
    children: [
      {
        path: 'index',
        component: () => import('@/views/gameswitch/index'),
        name: 'gameswitch',
        meta: { title: '功能开关', pername: 'gameswitchlist' }
      },
      {
        path: 'blockplayer',
        component: () => import('@/views/blockplayer/index'),
        name: 'blockplayer',
        meta: { title: '黑名单', pername: 'blockplayerlist' }
      },
      {
        path: 'whitelist',
        component: () => import('@/views/whitelist/index'),
        name: 'whitelist',
        meta: { title: '白名单', pername: 'whitelist' }
      },
      {
        path: 'superwhitelist',
        component: () => import('@/views/whitelist/super'),
        name: 'superwhitelist',
        meta: { title: '至尊白名单', pername: 'superwhitelist' }
      },
      {
        path: 'activecode',
        component: () => import('@/views/activecode/info'),
        name: 'activecode',
        meta: { title: '激活码', pername: 'activecode' }
      },
      {
        path: 'giftcode',
        component: () => import('@/views/giftcode/info'),
        name: 'giftcode',
        meta: { title: '生成兑换码', pername: 'giftcode' }
      },
      {
        path: 'giftcodeconfig',
        component: () => import('@/views/giftcode/config'),
        name: 'giftcodeconfig',
        meta: { title: '配置兑换码', pername: 'giftcodeconfig' }
      }
    ]
  }, {
    path: '/workertool',
    component: Layout,
    redirect: '/index',
    meta: {
      title: '运维工具',
      icon: 'el-icon-s-tools',
      pername: 'wokertool'
    },
    children: [
      {
        path: 'index',
        component: () => import('@/views/workertool/gameapi'),
        name: 'gameapi',
        meta: { title: 'php服务器配置', pername: 'gameapi' }
      },
      {
        path: 'apigate',
        component: () => import('@/views/workertool/apigate'),
        name: 'apigate',
        meta: { title: 'apigate服务器配置', pername: 'apigate' }
      }
    ]
  }
//  {
//     path: '/permission',
//     component: Layout,
//     redirect: '/permission/page',
//     alwaysShow: true, // will always show the root menu
//     name: 'Permission',
//     meta: {
//       title: 'permission',
//       icon: 'lock',
//       roles: ['admin', 'editor'] // you can set roles in root nav
//     },
//     children: [
//       {
//         path: 'page',
//         component: () => import('@/views/permission/page'),
//         name: 'PagePermission',
//         meta: {
//           title: 'pagePermission',
//           roles: ['admin'] // or you can only set roles in sub nav
//         }
//       },
//       {
//         path: 'directive',
//         component: () => import('@/views/permission/directive'),
//         name: 'DirectivePermission',
//         meta: {
//           title: 'directivePermission'
//           // if do not set roles, means: this page does not require permission
//         }
//       },
//       {
//         path: 'role',
//         component: () => import('@/views/permission/role'),
//         name: 'RolePermission',
//         meta: {
//           title: 'rolePermission',
//           roles: ['admin']
//         }
//       }
//     ]
//   },
//
//   {
//     path: '/icon',
//     component: Layout,
//     children: [
//       {
//         path: 'index',
//         component: () => import('@/views/icons/index'),
//         name: 'Icons',
//         meta: { title: 'icons', icon: 'icon', noCache: true }
//       }
//     ]
//   },
//
//   /** when your routing map is too long, you can split it into small modules **/
//   componentsRouter,
//   chartsRouter,
//   nestedRouter,
//   tableRouter,
//
//   {
//     path: '/example',
//     component: Layout,
//     redirect: '/example/list',
//     name: 'Example',
//     meta: {
//       title: 'example',
//       icon: 'el-icon-s-help'
//     },
//     children: [
//       {
//         path: 'create',
//         component: () => import('@/views/example/create'),
//         name: 'CreateArticle',
//         meta: { title: 'createArticle', icon: 'edit' }
//       },
//       {
//         path: 'edit/:id(\\d+)',
//         component: () => import('@/views/example/edit'),
//         name: 'EditArticle',
//         meta: { title: 'editArticle', noCache: true, activeMenu: '/example/list' },
//         hidden: true
//       },
//       {
//         path: 'list',
//         component: () => import('@/views/example/list'),
//         name: 'ArticleList',
//         meta: { title: 'articleList', icon: 'list' }
//       }
//     ]
//   },
//
//   {
//     path: '/tab',
//     component: Layout,
//     children: [
//       {
//         path: 'index',
//         component: () => import('@/views/tab/index'),
//         name: 'Tab',
//         meta: { title: 'tab', icon: 'tab' }
//       }
//     ]
//   },
//
//   {
//     path: '/error',
//     component: Layout,
//     redirect: 'noRedirect',
//     name: 'ErrorPages',
//     meta: {
//       title: 'errorPages',
//       icon: '404'
//     },
//     children: [
//       {
//         path: '401',
//         component: () => import('@/views/error-page/401'),
//         name: 'Page401',
//         meta: { title: 'page401', noCache: true }
//       },
//       {
//         path: '404',
//         component: () => import('@/views/error-page/404'),
//         name: 'Page404',
//         meta: { title: 'page404', noCache: true }
//       }
//     ]
//   },
//
//   {
//     path: '/error-log',
//     component: Layout,
//     children: [
//       {
//         path: 'log',
//         component: () => import('@/views/error-log/index'),
//         name: 'ErrorLog',
//         meta: { title: 'errorLog', icon: 'bug' }
//       }
//     ]
//   },
//
//   {
//     path: '/excel',
//     component: Layout,
//     redirect: '/excel/export-excel',
//     name: 'Excel',
//     meta: {
//       title: 'excel',
//       icon: 'excel'
//     },
//     children: [
//       {
//         path: 'export-excel',
//         component: () => import('@/views/excel/export-excel'),
//         name: 'ExportExcel',
//         meta: { title: 'exportExcel' }
//       },
//       {
//         path: 'export-selected-excel',
//         component: () => import('@/views/excel/select-excel'),
//         name: 'SelectExcel',
//         meta: { title: 'selectExcel' }
//       },
//       {
//         path: 'export-merge-header',
//         component: () => import('@/views/excel/merge-header'),
//         name: 'MergeHeader',
//         meta: { title: 'mergeHeader' }
//       },
//       {
//         path: 'upload-excel',
//         component: () => import('@/views/excel/upload-excel'),
//         name: 'UploadExcel',
//         meta: { title: 'uploadExcel' }
//       }
//     ]
//   },
//
//   {
//     path: '/zip',
//     component: Layout,
//     redirect: '/zip/download',
//     alwaysShow: true,
//     name: 'Zip',
//     meta: { title: 'zip', icon: 'zip' },
//     children: [
//       {
//         path: 'download',
//         component: () => import('@/views/zip/index'),
//         name: 'ExportZip',
//         meta: { title: 'exportZip' }
//       }
//     ]
//   },
//
//   {
//     path: '/pdf',
//     component: Layout,
//     redirect: '/pdf/index',
//     children: [
//       {
//         path: 'index',
//         component: () => import('@/views/pdf/index'),
//         name: 'PDF',
//         meta: { title: 'pdf', icon: 'pdf' }
//       }
//     ]
//   },
//   {
//     path: '/pdf/download',
//     component: () => import('@/views/pdf/download'),
//     hidden: true
//   },
//
//   {
//     path: '/theme',
//     component: Layout,
//     children: [
//       {
//         path: 'index',
//         component: () => import('@/views/theme/index'),
//         name: 'Theme',
//         meta: { title: 'theme', icon: 'theme' }
//       }
//     ]
//   },
//
//   {
//     path: '/clipboard',
//     component: Layout,
//     children: [
//       {
//         path: 'index',
//         component: () => import('@/views/clipboard/index'),
//         name: 'ClipboardDemo',
//         meta: { title: 'clipboardDemo', icon: 'clipboard' }
//       }
//     ]
//   },
//
//   {
//     path: 'external-link',
//     component: Layout,
//     children: [
//       {
//         path: 'https://github.com/PanJiaChen/vue-element-admin',
//         meta: { title: 'externalLink', icon: 'link' }
//       }
//     ]
//   },
//
//   // 404 page must be placed at the end !!!
//   { path: '*', redirect: '/404', hidden: true }
]

const createRouter = () => new Router({
  // mode: 'history', // require service support
  scrollBehavior: () => ({ y: 0 }),
  routes: constantRoutes
})

const router = createRouter()

// Detail see: https://github.com/vuejs/vue-router/issues/1234#issuecomment-357941465
export function resetRouter() {
  const newRouter = createRouter()
  router.matcher = newRouter.matcher // reset router
}

export default router
